@@ -1562,7 +1562,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type)
       (void) NormalizeImage(image);
       quantize_info=AcquireQuantizeInfo(image_info);
       quantize_info->number_colors=2;
-      quantize_info->dither_method=NoDitherMethod;
+      quantize_info->colorspace=GRAYColorspace;
       status=QuantizeImage(quantize_info,image);
       quantize_info=DestroyQuantizeInfo(quantize_info);
       image->matte=MagickFalse;
