@@ -1748,13 +1748,7 @@ static MagickBooleanType ValidateXMPProfile(const StringInfo *profile)
 #else
 static MagickBooleanType ValidateXMPProfile(const StringInfo *profile)
 {
-  char
-    *p;
-
-  p=StringLocateSubstring((const char *) GetStringInfoDatum(profile),"x:xmpmeta");
-  if (p != (char *) NULL)
-    p=StringLocateSubstring((const char *) GetStringInfoDatum(profile),"rdf:RDF");
-  return(p == (char *) NULL ? MagickFalse : MagickTrue);
+  return(MagickFalse);
 }
 #endif
 
@@ -1826,11 +1820,6 @@ static MagickBooleanType SetImageProfileInternal(Image *image,const char *name,
         if (recursive == MagickFalse)
           WriteTo8BimProfile(image,name,profile);
     }
-  /*
-    Inject profile into image properties.
-  */
-  (void) FormatLocaleString(property,MaxTextExtent,"%s:*",name);
-  (void) GetImageProperty(image,property);
   return(status);
 }
 
